;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "logview" "20251104.1725"
  "Major mode for viewing log files."
  '((emacs    "25.1")
    (datetime "0.8")
    (extmap   "1.0")
    (compat   "29"))
  :url "https://github.com/doublep/logview"
  :commit "9c97221dd04d7398df098e9f942efff016b60bbf"
  :revdesc "9c97221dd04d"
  :keywords '("files" "tools")
  :authors '(("Paul Pogonyshev" . "pogonyshev@gmail.com"))
  :maintainers '(("Paul Pogonyshev" . "pogonyshev@gmail.com")))
